==============================
Tasks target
==============================

LoadTargetList
---------------------

.. autoclass:: exorad.tasks.targetHandler.LoadTargetList
    :members:
    :undoc-members:
    :show-inheritance:

PrepareTarget
---------------------

.. autoclass:: exorad.tasks.targetHandler.PrepareTarget
    :members:
    :undoc-members:
    :show-inheritance:

UpdateTargetTable
---------------------

.. autoclass:: exorad.tasks.targetHandler.UpdateTargetTable
    :members:
    :undoc-members:
    :show-inheritance:

EstimateMaxSignal
---------------------

.. autoclass:: exorad.tasks.targetHandler.EstimateMaxSignal
    :members:
    :undoc-members:
    :show-inheritance:


ObserveTarget
---------------------

.. autoclass:: exorad.tasks.targetHandler.ObserveTarget
    :members:
    :undoc-members:
    :show-inheritance:


ObserveTargetlist
---------------------

.. autoclass:: exorad.tasks.targetHandler.ObserveTargetlist
    :members:
    :undoc-members:
    :show-inheritance:

